@@ -1,11 +1,12 @@
 // SPDX-License-Identifier: MIT
 
-use crate::{
+use netlink_packet_utils::{
     traits::{Emitable, Parseable},
     DecodeError,
 };
 
 #[derive(Clone, Copy, Eq, PartialEq, Debug)]
+#[non_exhaustive]
 pub struct Inet6CacheInfo {
     pub max_reasm_len: i32,
     pub tstamp: i32,
